#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.gallery.interfaces import IGalleryContainerTarget
from pyams_content.component.extfile.interfaces import IExtFileContainerTarget
from pyams_content.component.links.interfaces import ILinkContainerTarget
from pyams_content.component.paragraph.interfaces import IParagraphContainerTarget
from pyams_content.component.theme.interfaces import IThemesTarget
from pyams_content.shared.news.interfaces import INewsEvent, IWfNewsEvent, NEWS_CONTENT_TYPE, NEWS_CONTENT_NAME

# import packages
from pyams_content.shared.common import SharedContent, WfSharedContent, register_content_type
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty


@implementer(IWfNewsEvent, IParagraphContainerTarget, IThemesTarget, IExtFileContainerTarget, ILinkContainerTarget,
             IGalleryContainerTarget)
class WfNewsEvent(WfSharedContent):
    """Base news event"""

    content_type = NEWS_CONTENT_TYPE
    content_name = NEWS_CONTENT_NAME

    displayed_publication_date = FieldProperty(IWfNewsEvent['displayed_publication_date'])
    push_end_date = FieldProperty(IWfNewsEvent['push_end_date'])

register_content_type(WfNewsEvent)


@implementer(INewsEvent)
class NewsEvent(SharedContent):
    """Workflow managed news event class"""

    content_class = WfNewsEvent
